==> spectus_tus_uploader-0.0.10.tar.gz: ios/Classes/APImagePicker.swift <==
//
//  APImagePicker.swift
//  LocalTeams
//
//  Created by Akash Patel on 16/12/19.
//  Copyright © 2019 Akash Patel. All rights reserved.
//

import UIKit
import Photos

var selectedImageData : Data?

enum LTImagePickerSouceMode {
    case camera, photoLibrary, both
}

class APImagePicker : NSObject, UIImagePickerControllerDelegate, UINavigationControllerDelegate {
    
    class var sharedInstance :APImagePicker? {
        struct pickerStruct {
            static let instance = APImagePicker()
        }
        return pickerStruct.instance
    }
    
    var didSelectImage : ((_ selectedImage : UIImage)->Void)?
    var didSelectVideo : ((_ mediaPath : String)->Void)?
    var didRemovedImage : (()->Void)?
    var needToEditImage : Bool = false
    
    func pickVideoFrom(requiredEditting: Bool, completion: @escaping (_ mediaPath : String)->Void) {
        
        DispatchQueue.main.async {
            self.didSelectVideo = completion
            
            let imagePickerController = UIImagePickerController.init()
            imagePickerController.delegate = self
            imagePickerController.allowsEditing = requiredEditting
            imagePickerController.mediaTypes = ["public.movie"]
            
            imagePickerController.sourceType = .photoLibrary
            print("Method Call: ImagePicker Inside")
            (UIApplication.shared.windows[0].rootViewController)?.present(imagePickerController, animated: true, completion: nil)
        }
    }
    
    /*func pickImageFrom(controller : UIViewController,sourceType : LTImagePickerSouceMode, requiredEditting: Bool, completion: @escaping (_ selectedImage : UIImage)->Void, needRemoveButton : Bool = false, removePhotoHandler : (()->Void)? = nil) {
        
        DispatchQueue.main.async {
            self.didSelectImage = completion
            self.needToEditImage = requiredEditting
            self.didRemovedImage = removePhotoHandler
            
            let imagePickerController = UIImagePickerController.init()
            imagePickerController.delegate = self
            imagePickerController.allowsEditing = requiredEditting
            
            if sourceType == .camera {
                imagePickerController.sourceType = .camera
                controller.present(imagePickerController, animated: true, completion: nil)
            }
            else if sourceType == .photoLibrary {
                imagePickerController.sourceType = .photoLibrary
                controller.present(imagePickerController, animated: true, completion: nil)
            }
            else {
                DispatchQueue.main.async {
                    let actionSheetController = UIAlertController.init(title: "Alert", message: nil, preferredStyle: .actionSheet)
                    
                    //Camera Action
                    let actionCamera = UIAlertAction.init(title: ButtonTitle.Camera, style: .default) { (cameraAction) in
                        imagePickerController.sourceType = .camera
                        controller.present(imagePickerController, animated: true, completion: nil)
                    }
                    actionSheetController.addAction(actionCamera)
                    
                    //Photo Library Action
                    let actionPhotoLibrary = UIAlertAction.init(title: ButtonTitle.PhotoLibrary, style: .default) { (photoLibraryAction) in
                        imagePickerController.sourceType = .photoLibrary
                        controller.present(imagePickerController, animated: true, completion: nil)
                    }
                    actionSheetController.addAction(actionPhotoLibrary)
                    
                    if needRemoveButton, removePhotoHandler != nil {
                        let actionRemovePhoto = UIAlertAction.init(title: ButtonTitle.RemovePhoto, style: .destructive) { (removeAction) in
                            self.didRemovedImage?()
                        }
                        actionSheetController.addAction(actionRemovePhoto)
                    }
                    
                    //Cancel Action
                    let actionCancel = UIAlertAction.init(title: ButtonTitle.Cancel, style: .cancel, handler: nil)
                    actionSheetController.addAction(actionCancel)
                    
                    controller.present(actionSheetController, animated: true, completion: nil)
                }
            }
        }
    }*/
    
    //MARK: - ImagePicker Delegate
    func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
        picker.dismiss(animated: true, completion: nil)
    }
    
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [UIImagePickerController.InfoKey : Any]) {
        //UIImagePickerController.InfoKey.imageURL
        print("Method Call: DidFinish" + info.description)
        if let url = info[.mediaURL] as? URL {
            // Do something with the URL
            if self.didSelectVideo != nil {
                self.didSelectVideo?(url.absoluteString)
            }
        }
        
        /*if let imgURL = info[UIImagePickerController.InfoKey.imageURL] as? String, let url = URL.init(string: imgURL) {//info[UIImagePickerController.InfoKey(rawValue: UIImagePickerController.InfoKey.phAsset.rawValue)] as? URL {
            let result = PHAsset.fetchAssets(withALAssetURLs: [url], options: nil)
            if let asset = result.firstObject {
                let manager = PHImageManager.default()
                manager.requestImageData(for: asset, options: nil) { imageData, dataUTI, orientation, info in
                    if let fileURL = info!["PHImageFileURLKey"] as? URL {
                        let filename = fileURL.lastPathComponent
                        // use filename here
                        
                        if self.didSelectVideo != nil {
                            self.didSelectVideo?(fileURL.absoluteString)
                        }
                    }

                    // use imageData here
                    selectedImageData = imageData
                }
            }
        }
        
        
        if self.needToEditImage, let selectedImage = info[UIImagePickerController.InfoKey(rawValue: UIImagePickerController.InfoKey.editedImage.rawValue)] as? UIImage {
            self.didSelectImage?(selectedImage)
        }
        else if let selectedImage = info[UIImagePickerController.InfoKey(rawValue: UIImagePickerController.InfoKey.originalImage.rawValue)] as? UIImage {
            self.didSelectImage?(selectedImage)
        }*/
        picker.dismiss(animated: true, completion: nil)
    }
}

==> spectus_tus_uploader-0.0.11.tar.gz: ios/Classes/APImagePicker.swift <==
//
//  APImagePicker.swift
//  LocalTeams
//
//  Created by Akash Patel on 16/12/19.
//  Copyright © 2019 Akash Patel. All rights reserved.
//

import UIKit
import Photos

var selectedImageData : Data?

enum LTImagePickerSouceMode {
    case camera, photoLibrary, both
}

class APImagePicker : NSObject, UIImagePickerControllerDelegate, UINavigationControllerDelegate {
    
    class var sharedInstance :APImagePicker? {
        struct pickerStruct {
            static let instance = APImagePicker()
        }
        return pickerStruct.instance
    }
    
    var didSelectImage : ((_ selectedImage : UIImage)->Void)?
    var didSelectVideo : ((_ mediaPath : String)->Void)?
    var didRemovedImage : (()->Void)?
    var needToEditImage : Bool = false
    
    func pickVideoFrom(requiredEditting: Bool, completion: @escaping (_ mediaPath : String)->Void) {
        
        DispatchQueue.main.async {
            self.didSelectVideo = completion
            
            let imagePickerController = UIImagePickerController.init()
            imagePickerController.delegate = self
            imagePickerController.allowsEditing = requiredEditting
            imagePickerController.mediaTypes = ["public.movie"]
            
            imagePickerController.sourceType = .photoLibrary
            print("Method Call: ImagePicker Inside")
            (UIApplication.shared.windows[0].rootViewController)?.present(imagePickerController, animated: true, completion: nil)
        }
    }
    
    /*func pickImageFrom(controller : UIViewController,sourceType : LTImagePickerSouceMode, requiredEditting: Bool, completion: @escaping (_ selectedImage : UIImage)->Void, needRemoveButton : Bool = false, removePhotoHandler : (()->Void)? = nil) {
        
        DispatchQueue.main.async {
            self.didSelectImage = completion
            self.needToEditImage = requiredEditting
            self.didRemovedImage = removePhotoHandler
            
            let imagePickerController = UIImagePickerController.init()
            imagePickerController.delegate = self
            imagePickerController.allowsEditing = requiredEditting
            
            if sourceType == .camera {
                imagePickerController.sourceType = .camera
                controller.present(imagePickerController, animated: true, completion: nil)
            }
            else if sourceType == .photoLibrary {
                imagePickerController.sourceType = .photoLibrary
                controller.present(imagePickerController, animated: true, completion: nil)
            }
            else {
                DispatchQueue.main.async {
                    let actionSheetController = UIAlertController.init(title: "Alert", message: nil, preferredStyle: .actionSheet)
                    
                    //Camera Action
                    let actionCamera = UIAlertAction.init(title: ButtonTitle.Camera, style: .default) { (cameraAction) in
                        imagePickerController.sourceType = .camera
                        controller.present(imagePickerController, animated: true, completion: nil)
                    }
                    actionSheetController.addAction(actionCamera)
                    
                    //Photo Library Action
                    let actionPhotoLibrary = UIAlertAction.init(title: ButtonTitle.PhotoLibrary, style: .default) { (photoLibraryAction) in
                        imagePickerController.sourceType = .photoLibrary
                        controller.present(imagePickerController, animated: true, completion: nil)
                    }
                    actionSheetController.addAction(actionPhotoLibrary)
                    
                    if needRemoveButton, removePhotoHandler != nil {
                        let actionRemovePhoto = UIAlertAction.init(title: ButtonTitle.RemovePhoto, style: .destructive) { (removeAction) in
                            self.didRemovedImage?()
                        }
                        actionSheetController.addAction(actionRemovePhoto)
                    }
                    
                    //Cancel Action
                    let actionCancel = UIAlertAction.init(title: ButtonTitle.Cancel, style: .cancel, handler: nil)
                    actionSheetController.addAction(actionCancel)
                    
                    controller.present(actionSheetController, animated: true, completion: nil)
                }
            }
        }
    }*/
    
    //MARK: - ImagePicker Delegate
    func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
        picker.dismiss(animated: true, completion: nil)
    }
    
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [UIImagePickerController.InfoKey : Any]) {
        //UIImagePickerController.InfoKey.imageURL
        print("Method Call: DidFinish" + info.description)
//         if let url = info[.mediaURL] as? URL {
//             // Do something with the URL
//             if self.didSelectVideo != nil {
//                 self.didSelectVideo?(url.absoluteString)
//             }
//         }
        
        if let imgURL = info[UIImagePickerController.InfoKey.imageURL] as? String, let url = URL.init(string: imgURL) {//info[UIImagePickerController.InfoKey(rawValue: UIImagePickerController.InfoKey.phAsset.rawValue)] as? URL {
            let result = PHAsset.fetchAssets(withALAssetURLs: [url], options: nil)
            if let asset = result.firstObject {
                let manager = PHImageManager.default()
                manager.requestImageData(for: asset, options: nil) { imageData, dataUTI, orientation, info in
                    if let fileURL = info!["PHImageFileURLKey"] as? URL {
                        let filename = fileURL.lastPathComponent
                        // use filename here
                        
                        if self.didSelectVideo != nil {
                            self.didSelectVideo?(fileURL.absoluteString)
                        }
                    }

                    // use imageData here
                    selectedImageData = imageData
                }
            }
        }
        
        
        if self.needToEditImage, let selectedImage = info[UIImagePickerController.InfoKey(rawValue: UIImagePickerController.InfoKey.editedImage.rawValue)] as? UIImage {
            self.didSelectImage?(selectedImage)
        }
        else if let selectedImage = info[UIImagePickerController.InfoKey(rawValue: UIImagePickerController.InfoKey.originalImage.rawValue)] as? UIImage {
            self.didSelectImage?(selectedImage)
        }
        picker.dismiss(animated: true, completion: nil)
    }
}
